# Copyright (c) 2000-2005, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

%define section   free
%define base_name commons-transaction
%define jakarta_version 1.1

# If you don't want to build with maven, and use straight ant instead,
# give rpmbuild option '--without maven'

%define _without_maven 1

%define with_maven %{!?_without_maven:1}%{?_without_maven:0}
%define without_maven %{?_without_maven:1}%{!?_without_maven:0}

Name:           jakarta-commons-transaction
Version:        %{jakarta_version}
Release:        3jpp.1.ep1.3%{?dist}.1
Epoch:          0
Summary:        Commons Transaction
License:        Apache License 2.0
Url:            http://jakarta.apache.org/commons/transaction/
Group:          Development/Libraries/Java
Source0:	commons-transaction-1.1-src.tgz

Source1:        pom-maven2jpp-depcat.xsl
Source2:        pom-maven2jpp-newdepmap.xsl
Source3:        pom-maven2jpp-mapdeps.xsl
Source4:        commons-transaction-1.1-jpp-depmap.xml

Patch0:         commons-transaction-1.1-project_xml.patch
Patch1:         commons-transaction-1.1-targetdefault.patch

Requires:   jpackage-utils >= 0:1.6
Requires:	jakarta-commons-codec
Requires:	geronimo-j2ee-1.4-apis
Requires:	log4j

BuildRequires:  jpackage-utils >= 0:1.6
BuildRequires:  ant >= 0:1.6
%if %{with_maven}
BuildRequires:  maven >= 0:1.0.2
BuildRequires:  maven-plugins-base
BuildRequires:  maven-plugin-test
BuildRequires:  maven-plugin-xdoc
BuildRequires:  maven-plugin-license
BuildRequires:  saxon
BuildRequires:  saxon-scripts
%else
BuildRequires:  ant-junit >= 0:1.6
%endif
BuildRequires:  junit
BuildRequires:	jakarta-commons-codec
BuildRequires:	geronimo-j2ee-1.4-apis
BuildRequires:	log4j
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-buildroot

%description
Commons Transaction aims at providing lightweight, 
standardized, well tested and efficient implementations 
of utility classes commonly used in transactional Java 
programming. Initially there are implementations for 
multi level locks, transactional collections and 
transactional file access. There may be additional 
implementations when the common need for them becomes 
obvious. However, the complete component shall remain 
compatible to JDK1.2 and should have minimal dependencies.

%package javadoc
Summary:	Javadoc for %{name}
Group:		Development/Documentation

%description javadoc
%{summary}.

%prep
rm -rf $RPM_BUILD_ROOT
%setup -q -c -n %{base_name}
find . -name "*.jar" -exec rm -f {} \;
#for j in $(find . -name "*.jar"); do
#	mv $j $j.no
#done

%if %{with_maven}

export DEPCAT=$(pwd)/commons-transaction-1.1-depcat.new.xml
echo '<?xml version="1.0" standalone="yes"?>' > $DEPCAT
echo '<depset>' >> $DEPCAT
for p in $(find . -name project.xml); do
    pushd $(dirname $p)
    /usr/bin/saxon project.xml %{SOURCE1} >> $DEPCAT
    popd
done
echo >> $DEPCAT
echo '</depset>' >> $DEPCAT
/usr/bin/saxon $DEPCAT %{SOURCE2} > commons-transaction-1.1-depmap.new.xml

%else

gzip -dc %{SOURCE5} | tar xf -
build-jar-repository lib/ commons-codec geronimo-j2ee-1.4-apis junit log4j

%endif

%patch0 -b .sav
%patch1 -b .sav

%build

%if %{with_maven}
for p in $(find . -name project.xml); do
    pushd $(dirname $p)
    cp project.xml project.xml.orig
    /usr/bin/saxon -o project.xml project.xml.orig %{SOURCE3} map=%{SOURCE4}
    popd
done

for p in $(find . -name project.properties); do
    echo >> $p
    echo maven.repo.remote=file:/usr/share/maven-1.0/repository >> $p
    echo maven.home.local=$(pwd)/.maven >> $p
done

mkdir -p .maven/repository/JPP/jars
build-jar-repository -s -p .maven/repository/JPP/jars \
commons-codec \
geronimo-j2ee-1.4-apis \
junit \
log4j \
xerces-j2 \
xml-commons-apis \


mkdir -p .maven/repository/maven/jars
build-jar-repository .maven/repository/maven/jars \
maven-jelly-tags \


maven -Dmaven.repo.remote=file:/usr/share/maven/repository \
      -Dmaven.javadoc.source=1.4 \
      -Dmaven.home.local=$(pwd)/.maven \
      jar javadoc 
%else
ant jar javadocs
%endif

%install
# jars
install -d -m 755 $RPM_BUILD_ROOT%{_javadir}

%if %{with_maven}
install -m 644 target/commons-transaction-1.1.jar \
           $RPM_BUILD_ROOT%{_javadir}/%{name}-%{version}.jar
%else
install -m 644 build/lib/commons-transaction-1.1.jar \
           $RPM_BUILD_ROOT%{_javadir}/%{name}-%{version}.jar
%endif

(cd $RPM_BUILD_ROOT%{_javadir} && for jar in jakarta-*; do \
ln -sf ${jar} ${jar/jakarta-/}; done)
(cd $RPM_BUILD_ROOT%{_javadir} && for jar in *-%{version}*; do \
ln -sf ${jar} ${jar/-%{version}/}; done)

# javadoc
install -d -m 755 $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}

%if %{with_maven}
cp -pr target/docs/apidocs/* $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}
%else
cp -pr build/doc/apidocs/* $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}
%endif

touch $RPM_BUILD_ROOT%{_javadocdir}/%{name} # ghost symlink
rm -rf target/docs/apidocs

## manual
install -d -m 755 $RPM_BUILD_ROOT%{_docdir}/%{name}-%{version}
cp -p LICENSE.txt $RPM_BUILD_ROOT%{_docdir}/%{name}-%{version}

%clean
rm -rf $RPM_BUILD_ROOT

%post javadoc
ln -sf %{name}-%{version} %{_javadocdir}/%{name}
 
%postun javadoc
if [ "$1" = "0" ]; then
  rm -f %{_javadocdir}/%{name}
fi

%files
%defattr(0644,root,root,0755)
%{_docdir}/%{name}-%{version}/LICENSE.txt
%{_javadir}/*

%files javadoc
%defattr(0644,root,root,0755)
%{_javadocdir}/%{name}-%{version}
%ghost %{_javadocdir}/%{name}

%changelog
* Thu Jul 26 2007 Fernando Nasser <fnasser@redhat.com> 0:1.1-3jpp.1.ep1.3.1
- Rebuild with JDK 1.4

* Fri Jul 20 2007 Deepak Bhole <dbhole@redhat.com> 0:1.1-3jpp.1.ep1.3
- Remove ant 1.4 target

* Fri Jul 06 2007 Deepak Bhole <dbhole@redhat.com> 0:1.1-3jpp.1.ep1.2
- Added ant build support

* Mon Mar 12 2007 Fernando Nasser <fnasser@redhat.com> 0:1.1-3jpp.1.ep1.1
- Rebuild

* Mon Mar 05 2007 Fernando Nasser <fnasser@redhat.com> 0:1.1-3jpp.1.el4ep1.2
- Fix name of artifact for J2EE APIs JAR
- Rebuild

* Mon Mar 05 2007 Fernando Nasser <fnasser@redhat.com> 0:1.1-3jpp.1.el4ep1.1
- Use more specific geronimo-j2ee-1.4-apis dependency

* Sun Mar 12 2006 Fernando Nasser <fnasser@redhat.com> 0:1.1-3jpp_1rh
- First Red Hat build
- Add missing dependency on jakarta-commons-beanutils

* Mon Feb 13 2006 Ralph Apel <r.apel@r-apel.de> 0:1.1-3jpp
- Fix project.xml format
- Fix depmap.xml format

* Tue Dec 06 2005 Fernando Nasser <fnasser@redhat.com> 0:1.1-2jpp
- Add header

* Tue Dec 06 2005 Fernando Nasser <fnasser@redhat.com> 0:1.1-1jpp
- Re-mavenize for JPP 1.7

* Mon Sep 05 2005 Ralph Apel <r.apel@r-apel.de> 0:1.1-1jpp
- First release
